@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """Gaia class file."""
 import json
+import logging
 import os
 from datetime import datetime
 
@@ -11,8 +12,9 @@ from google.cloud.secretmanager_v1 import SecretManagerServiceClient
 
 from .auth import Auth
 
-CONFIG_BUCKET = os.environ.get("CONFIG_BUCKET")
+# ASSETS_BUCKET = os.environ.get("ASSETS_BUCKET")
 BIGQUERY_IMPORTS_BUCKET = os.environ.get("BIGQUERY_IMPORTS_BUCKET")
+CONFIG_BUCKET = os.environ.get("CONFIG_BUCKET")
 FIRESTORE_IMPORTS_BUCKET = os.environ.get("FIRESTORE_IMPORTS_BUCKET")
 
 
@@ -83,9 +85,9 @@ class Gaia:
     def save_bigquery_import(self, dataset, table, entries):
         """Save entries to import bucket."""
         bucketname = BIGQUERY_IMPORTS_BUCKET
-        print(f"Bucket Name: {bucketname}")
+        print(f"BigQuery Bucket Name: {bucketname}")
         blobname = f"{dataset}/{table}.json"
-        print(f"Blob Name: {blobname}")
+        print(f"BigQuery Blob Name: {blobname}")
         blobstring = "\n".join([json.dumps(e, default=str) for e in entries])
         blob = storage.Client().bucket(bucketname).blob(blobname)
         blob.upload_from_string(blobstring, content_type="application/json")
@@ -94,11 +96,30 @@ class Gaia:
     def save_firestore_import(self, dataset, table, entries):
         """Save entries to import bucket."""
         bucketname = FIRESTORE_IMPORTS_BUCKET
-        print(f"Bucket Name: {bucketname}")
+        print(f"Firestore Bucket Name: {bucketname}")
         timestamp = datetime.isoformat(datetime.now())
         blobname = f"{dataset}/{dataset}_{table}_{timestamp}.json"
-        print(f"Blob Name: {blobname}")
+        print(f"Firestore Blob Name: {blobname}")
         blobstring = json.dumps(entries, sort_keys=True, default=str)
         blob = storage.Client().bucket(bucketname).blob(blobname)
         blob.upload_from_string(blobstring, content_type="application/json")
         return blob
+
+    def save_import(self, dataset, table, entries, description=None, bigquery=True, firestore=True):
+        """Save an import in bigquery and/or firestore."""
+        if not description:
+            description = f"{dataset}_{table}"
+        if firestore:
+            try:
+                print(f"Saving {description} for Firestore...")
+                blob = self.save_firestore_import(dataset, table, entries)
+                print(f"Saved {description} to gs://{blob.bucket.name}/{blob.name}.")
+            except Exception as error:
+                logging.error(f"Failed saving {description} for Firestore: {error}")
+        if bigquery:
+            try:
+                print(f"Saving {description} for BigQuery...")
+                blob = self.save_bigquery_import(dataset, table, entries)
+                print(f"Saved {description} to gs://{blob.bucket.name}/{blob.name}.")
+            except Exception as error:
+                logging.error(f"Failed saving {description} for BigQuery: {error}")
