@@ -47,6 +47,11 @@ class Auth:
             key=self.gaia.get_secret(settings.get("key_name")),
         )
 
+    def google(self, scopes):
+        """Return an authorized Google instance for gaia."""
+        from bits.google import Google
+        return Google(scopes=scopes)
+
     def people_mysql(self):
         """Return an authorized MySQL instance for People."""
         from bits.mysql import MySQL
